==> rivendell-1.7.2.tar.gz: rivendell-1.7.2/rdairplay/rdairplay_nb.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditEvent</name>
    <message>
        <source>Edit Event</source>
        <translation>Rediger hending</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Start på:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Handling viss førre hending spelar enno</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Start med ein gong</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Lag neste</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Vent opp til</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spel</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Overgang</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="obsolete">Overlapp</translation>
    </message>
    <message>
        <source>Start Transition Type:</source>
        <translation>Start overtoningstype:</translation>
    </message>
    <message>
        <source>No Fade at Segue Out</source>
        <translation>Inga toning ved Overgang ut</translation>
    </message>
    <message>
        <source>&amp;Audition</source>
        <translation>&amp;Lytt</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Edit Marker</source>
        <translation>Rediger markør</translation>
    </message>
    <message>
        <source>Edit Track</source>
        <translation>Rediger spor</translation>
    </message>
    <message>
        <source>Edit Log Track</source>
        <translation>Rediger loggspor</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Overtoning viss førre korga endar før</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLog</name>
    <message>
        <source>EST TIME</source>
        <translation>OMTR TID</translation>
    </message>
    <message>
        <source>LEN</source>
        <translation>LENGD</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation>OVERT</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>KORG</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITTEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>ARTIST</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation>TID</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>KLIENT</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGENT</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation>SELSKAP</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation>LINJE-ID</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation>TELLING</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation>STATUS</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vel</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Spel</translation>
    </message>
    <message>
        <source>Make
Next</source>
        <translation>Lag
neste</translation>
    </message>
    <message>
        <source>Modify</source>
        <translation>Endre</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Rull</translation>
    </message>
    <message>
        <source>Refresh
Log</source>
        <translation>Last loggen
på nytt</translation>
    </message>
    <message>
        <source>Select
Log</source>
        <translation>Vel
logg</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Loggen eksisterer</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation>Loggen finst frå før!</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- slutt på loggen ---</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>SPEL</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>STOPP</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>OVERGANG</translation>
    </message>
    <message>
        <source>OVERLAP</source>
        <translation type="obsolete">OVERLAPP</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKØR</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>SPOR</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LENKJE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikkimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[trafikkimport]</translation>
    </message>
    <message>
        <source>CHAIN TO</source>
        <translation>LENK TIL</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[FANN IKKJE KORG]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[GYLDIG KUTT FINST IKKJE</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[LYD FINST IKKJE]</translation>
    </message>
    <message>
        <source>T</source>
        <translation>S</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition
Head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition
Tail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Start</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation>Vel ein logg</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NAMN</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>SKILDRING</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>TENEST</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Last</translation>
    </message>
    <message>
        <source>Unload</source>
        <translation>Last ut</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Lagre &amp;som</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Rename Log</source>
        <translation>Døyp om loggen</translation>
    </message>
</context>
<context>
    <name>LogLineBox</name>
    <message>
        <source>STOP</source>
        <translation>STOPP</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>SPEL</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>OVERGANG</translation>
    </message>
    <message>
        <source>OVRLAP</source>
        <translation type="obsolete">OVERLAPP</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[FANN IKKJE KORG]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[LYD FINST IKKJE]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[GYLDIG KUTT FINST IKKJE</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKØR</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>SPOR</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LENKJE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikkimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[trafikkimport]</translation>
    </message>
    <message>
        <source>CHAIN</source>
        <translation>LENKJE</translation>
    </message>
    <message>
        <source>T</source>
        <translation>S</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDAirPlay</source>
        <translation>RDAirPlay</translation>
    </message>
    <message>
        <source>Multiple instances not allowed!</source>
        <translation>Det er ikkje lov med fleire førekomstar!</translation>
    </message>
    <message>
        <source>RDAirPlay - Host:</source>
        <translation>RDAirPlay-vert:</translation>
    </message>
    <message>
        <source>Database Error</source>
        <translation>Databasefeil</translation>
    </message>
    <message>
        <source>ADD</source>
        <translation>LEGG TIL</translation>
    </message>
    <message>
        <source>DEL</source>
        <translation>SLETT</translation>
    </message>
    <message>
        <source>MOVE</source>
        <translation>FLYTT</translation>
    </message>
    <message>
        <source>COPY</source>
        <translation>KOPIER</translation>
    </message>
    <message>
        <source>Main Log
[--]</source>
        <translation>Hovudlogg
[---]</translation>
    </message>
    <message>
        <source>Aux 1 Log
[--]</source>
        <translation>Hjelpelogg 1
[---]</translation>
    </message>
    <message>
        <source>Aux 2 Log
[--]</source>
        <translation>Hjelpelogg 2
[---]</translation>
    </message>
    <message>
        <source>Sound
Panel</source>
        <translation>Lyd-
panel</translation>
    </message>
    <message>
        <source>Main Log</source>
        <translation>Hovudlogg</translation>
    </message>
    <message>
        <source>Aux 1 Log</source>
        <translation>Hjelpelogg 1</translation>
    </message>
    <message>
        <source>Aux 2 Log</source>
        <translation>Hjelpelogg 2</translation>
    </message>
    <message>
        <source>LOG
REFRESHING</source>
        <translation>LOGGEN
LASTAR PÅ NYTT</translation>
    </message>
    <message>
        <source>Exit RDAirPlay?</source>
        <translation>Gå ut av RDAirPlay?</translation>
    </message>
</context>
<context>
    <name>ModeDisplay</name>
    <message>
        <source>Operating Mode</source>
        <translation>Køyremodus</translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation>Live-hjelp</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuelt</translation>
    </message>
</context>
<context>
    <name>PostCounter</name>
    <message>
        <source>Next Timed Start</source>
        <translation>Neste tidlagte star</translation>
    </message>
    <message>
        <source>On Time</source>
        <translation>På tida</translation>
    </message>
    <message>
        <source>Next Timed Start [--:--:--]</source>
        <translation>Neste tidlagte start [--:--:--]</translation>
    </message>
</context>
<context>
    <name>StopCounter</name>
    <message>
        <source>Next Stop [none]</source>
        <translation>Neste stopp [ingen]</translation>
    </message>
    <message>
        <source>Next Stop</source>
        <translation>Neste stopp</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Stoppa</translation>
    </message>
</context>
</TS>

==> rivendell-2.5.0.tar.gz: rivendell-2.5.0/rdairplay/rdairplay_nb.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>EditEvent</name>
    <message>
        <source>Edit Event</source>
        <translation>Rediger hending</translation>
    </message>
    <message>
        <source>Start at:</source>
        <translation>Start på:</translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation>Handling viss førre hending spelar enno</translation>
    </message>
    <message>
        <source>Start Immediately</source>
        <translation>Start med ein gong</translation>
    </message>
    <message>
        <source>Make Next</source>
        <translation>Lag neste</translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation>Vent opp til</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Spel</translation>
    </message>
    <message>
        <source>Segue</source>
        <translation>Overgang</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Overlap</source>
        <translation type="obsolete">Overlapp</translation>
    </message>
    <message>
        <source>Start Transition Type:</source>
        <translation>Start overtoningstype:</translation>
    </message>
    <message>
        <source>No Fade at Segue Out</source>
        <translation>Inga toning ved Overgang ut</translation>
    </message>
    <message>
        <source>&amp;Audition</source>
        <translation>&amp;Lytt</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Stopp</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Start</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Avbryt</translation>
    </message>
    <message>
        <source>Edit Marker</source>
        <translation>Rediger markør</translation>
    </message>
    <message>
        <source>Edit Track</source>
        <translation>Rediger spor</translation>
    </message>
    <message>
        <source>Edit Log Track</source>
        <translation>Rediger loggspor</translation>
    </message>
    <message>
        <source>Transition If Previous Cart Ends Before</source>
        <translation>Overtoning viss førre korga endar før</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Start Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event is already scheduled with this start time!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HourSelector</name>
    <message>
        <source>12a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>12p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>6p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>8p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>9p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10p</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>11p</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLog</name>
    <message>
        <source>EST TIME</source>
        <translation>OMTR TID</translation>
    </message>
    <message>
        <source>LEN</source>
        <translation>LENGD</translation>
    </message>
    <message>
        <source>TRANS</source>
        <translation>OVERT</translation>
    </message>
    <message>
        <source>CART</source>
        <translation>KORG</translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation>TITTEL</translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation>ARTIST</translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation>GRUPPE</translation>
    </message>
    <message>
        <source>TIME</source>
        <translation>TID</translation>
    </message>
    <message>
        <source>CLIENT</source>
        <translation>KLIENT</translation>
    </message>
    <message>
        <source>AGENCY</source>
        <translation>AGENT</translation>
    </message>
    <message>
        <source>LABEL</source>
        <translation>SELSKAP</translation>
    </message>
    <message>
        <source>LINE ID</source>
        <translation>LINJE-ID</translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation>TELLING</translation>
    </message>
    <message>
        <source>STATUS</source>
        <translation>STATUS</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Vel</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="obsolete">Spel</translation>
    </message>
    <message>
        <source>Make
Next</source>
        <translation>Lag
neste</translation>
    </message>
    <message>
        <source>Modify</source>
        <translation>Endre</translation>
    </message>
    <message>
        <source>Scroll</source>
        <translation>Rull</translation>
    </message>
    <message>
        <source>Refresh
Log</source>
        <translation>Last loggen
på nytt</translation>
    </message>
    <message>
        <source>Select
Log</source>
        <translation>Vel
logg</translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation>Loggen eksisterer</translation>
    </message>
    <message>
        <source>Log Already Exists!</source>
        <translation>Loggen finst frå før!</translation>
    </message>
    <message>
        <source>--- end of log ---</source>
        <translation>--- slutt på loggen ---</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>SPEL</translation>
    </message>
    <message>
        <source>STOP</source>
        <translation>STOPP</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>OVERGANG</translation>
    </message>
    <message>
        <source>OVERLAP</source>
        <translation type="obsolete">OVERLAPP</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKØR</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>SPOR</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LENKJE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikkimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[trafikkimport]</translation>
    </message>
    <message>
        <source>CHAIN TO</source>
        <translation>LENK TIL</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[FANN IKKJE KORG]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[GYLDIG KUTT FINST IKKJE</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[LYD FINST IKKJE]</translation>
    </message>
    <message>
        <source>T</source>
        <translation>S</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pause</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Run Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next Stop:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log End:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition
Head</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audition
Tail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished">Start</translation>
    </message>
    <message>
        <source>Selected:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListLogs</name>
    <message>
        <source>Select a Log</source>
        <translation>Vel ein logg</translation>
    </message>
    <message>
        <source>NAME</source>
        <translation>NAMN</translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation>SKILDRING</translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation>TENEST</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Last</translation>
    </message>
    <message>
        <source>Unload</source>
        <translation>Last ut</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Lagre &amp;som</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Rename Log</source>
        <translation>Døyp om loggen</translation>
    </message>
</context>
<context>
    <name>LogLineBox</name>
    <message>
        <source>STOP</source>
        <translation>STOPP</translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation>SPEL</translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation>OVERGANG</translation>
    </message>
    <message>
        <source>OVRLAP</source>
        <translation type="obsolete">OVERLAPP</translation>
    </message>
    <message>
        <source>[CART NOT FOUND]</source>
        <translation>[FANN IKKJE KORG]</translation>
    </message>
    <message>
        <source>[NO AUDIO AVAILABLE]</source>
        <translation>[LYD FINST IKKJE]</translation>
    </message>
    <message>
        <source>[NO VALID CUT AVAILABLE]</source>
        <translation>[GYLDIG KUTT FINST IKKJE</translation>
    </message>
    <message>
        <source>MARKER</source>
        <translation>MARKØR</translation>
    </message>
    <message>
        <source>TRACK</source>
        <translation>SPOR</translation>
    </message>
    <message>
        <source>LINK</source>
        <translation>LENKJE</translation>
    </message>
    <message>
        <source>[music import]</source>
        <translation>[musikkimport]</translation>
    </message>
    <message>
        <source>[traffic import]</source>
        <translation>[trafikkimport]</translation>
    </message>
    <message>
        <source>CHAIN</source>
        <translation>LENKJE</translation>
    </message>
    <message>
        <source>T</source>
        <translation>S</translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDAirPlay</source>
        <translation>RDAirPlay</translation>
    </message>
    <message>
        <source>Multiple instances not allowed!</source>
        <translation>Det er ikkje lov med fleire førekomstar!</translation>
    </message>
    <message>
        <source>RDAirPlay - Host:</source>
        <translation type="obsolete">RDAirPlay-vert:</translation>
    </message>
    <message>
        <source>Database Error</source>
        <translation>Databasefeil</translation>
    </message>
    <message>
        <source>ADD</source>
        <translation>LEGG TIL</translation>
    </message>
    <message>
        <source>DEL</source>
        <translation>SLETT</translation>
    </message>
    <message>
        <source>MOVE</source>
        <translation>FLYTT</translation>
    </message>
    <message>
        <source>COPY</source>
        <translation>KOPIER</translation>
    </message>
    <message>
        <source>Main Log
[--]</source>
        <translation>Hovudlogg
[---]</translation>
    </message>
    <message>
        <source>Aux 1 Log
[--]</source>
        <translation>Hjelpelogg 1
[---]</translation>
    </message>
    <message>
        <source>Aux 2 Log
[--]</source>
        <translation>Hjelpelogg 2
[---]</translation>
    </message>
    <message>
        <source>Sound
Panel</source>
        <translation>Lyd-
panel</translation>
    </message>
    <message>
        <source>Main Log</source>
        <translation>Hovudlogg</translation>
    </message>
    <message>
        <source>Aux 1 Log</source>
        <translation>Hjelpelogg 1</translation>
    </message>
    <message>
        <source>Aux 2 Log</source>
        <translation>Hjelpelogg 2</translation>
    </message>
    <message>
        <source>LOG
REFRESHING</source>
        <translation>LOGGEN
LASTAR PÅ NYTT</translation>
    </message>
    <message>
        <source>Exit RDAirPlay?</source>
        <translation>Gå ut av RDAirPlay?</translation>
    </message>
    <message>
        <source>User:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ModeDisplay</name>
    <message>
        <source>Operating Mode</source>
        <translation>Køyremodus</translation>
    </message>
    <message>
        <source>LiveAssist</source>
        <translation>Live-hjelp</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuelt</translation>
    </message>
</context>
<context>
    <name>PostCounter</name>
    <message>
        <source>Next Timed Start</source>
        <translation>Neste tidlagte star</translation>
    </message>
    <message>
        <source>On Time</source>
        <translation>På tida</translation>
    </message>
    <message>
        <source>Next Timed Start [--:--:--]</source>
        <translation>Neste tidlagte start [--:--:--]</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished">STOPP</translation>
    </message>
    <message>
        <source>PAUSE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RESUME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WHERE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DELETE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOVE?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TO?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COPY?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ERROR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StopCounter</name>
    <message>
        <source>Next Stop [none]</source>
        <translation>Neste stopp [ingen]</translation>
    </message>
    <message>
        <source>Next Stop</source>
        <translation>Neste stopp</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Stoppa</translation>
    </message>
</context>
</TS>
